==> domframework_0.55.orig.tar.bz2: domframework-0.55/Tests/queuefileTest.php <==
<?php
/** DomFramework - Tests
  * @package domframework
  * @author Dominique Fournier <dominique@fournier38.fr>
  */

/** Test the queuefile.php file */
class test_queuefile extends PHPUnit_Framework_TestCase
{
  public function test_clean ()
  {
    if (file_exists ("/tmp/queuefileTest/queuefileTest.json"))
      unlink ("/tmp/queuefileTest/queuefileTest.json");
  }

  public function test_add1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->add ("test1");
    $this->assertSame (true, is_object ($res));
  }

  public function test_count1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->count ();
    $this->assertSame (1, $res);
  }

  public function test_add2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->add ("test2");
    $this->assertSame (true, is_object ($res));
  }

  public function test_count2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->count ();
    $this->assertSame (2, $res);
  }

  public function test_getFirst1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getFirst ();
    $this->assertSame ("test1", $res);
  }

  public function test_getLast1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getLast ();
    $this->assertSame ("test2", $res);
  }

  public function test_getRange1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getRange (1, 1);
    $this->assertSame (["test2"], $res);
  }

  public function test_getRange2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getRange (0, 2);
    $this->assertSame (["test1", "test2"], $res);
  }

  public function test_getRange3 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $this->expectException ();
    $res = $queuefile->getRange (0, 3);
  }

  public function test_getAll1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getAll ();
    $this->assertSame (["test1", "test2"], $res);
  }

  // AFTER THIS TEST THE FILE WILL BE EMPTY
  public function test_getAll2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->clear ();
    $this->assertSame (true, is_object ($res));
  }

  public function test_count3 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->count ();
    $this->assertSame (0, $res);
  }

  public function test_getAll3 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getAll ();
    $this->assertSame ([], $res);
  }

  public function test_getFirst2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getFirst ();
    $this->assertSame (null, $res);
  }

  public function test_getLast2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getLast ();
    $this->assertSame (null, $res);
  }

}

==> domframework_0.60.orig.tar.bz2: domframework-0.60/Tests/queuefileTest.php <==
<?php
/** DomFramework - Tests
  * @package domframework
  * @author Dominique Fournier <dominique@fournier38.fr>
  */

/** Test the queuefile.php file */
class queuefileTest extends PHPUnit_Framework_TestCase
{
  public function test_clean ()
  {
    if (file_exists ("/tmp/queuefileTest/queuefileTest.json"))
      unlink ("/tmp/queuefileTest/queuefileTest.json");
  }

  public function test_add1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->add ("test1");
    $this->assertSame (true, is_object ($res));
  }

  public function test_count1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->count ();
    $this->assertSame (1, $res);
  }

  public function test_add2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->add ("test2");
    $this->assertSame (true, is_object ($res));
  }

  public function test_count2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->count ();
    $this->assertSame (2, $res);
  }

  public function test_getFirst1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getFirst ();
    $this->assertSame ("test1", $res);
  }

  public function test_getLast1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getLast ();
    $this->assertSame ("test2", $res);
  }

  public function test_getRange1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getRange (1, 1);
    $this->assertSame (["test2"], $res);
  }

  public function test_getRange2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getRange (0, 2);
    $this->assertSame (["test1", "test2"], $res);
  }

  public function test_getRange3 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $this->expectException ();
    $res = $queuefile->getRange (0, 3);
  }

  public function test_getAll1 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getAll ();
    $this->assertSame (["test1", "test2"], $res);
  }

  // AFTER THIS TEST THE FILE WILL BE EMPTY
  public function test_getAll2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->clear ();
    $this->assertSame (true, is_object ($res));
  }

  public function test_count3 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->count ();
    $this->assertSame (0, $res);
  }

  public function test_getAll3 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getAll ();
    $this->assertSame ([], $res);
  }

  public function test_getFirst2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getFirst ();
    $this->assertSame (null, $res);
  }

  public function test_getLast2 ()
  {
    $queuefile = new queuefile ();
    $queuefile->connect ("file:///tmp/queuefileTest/queuefileTest.json");
    $res = $queuefile->getLast ();
    $this->assertSame (null, $res);
  }

}
